@@ -7,17 +7,19 @@
 #ifndef AUTH_WIDGET_H_
 #define AUTH_WIDGET_H_
 
-#include <Wt/Auth/AuthWidget>
+#include <Wt/Auth/AuthWidget.h>
+
+using namespace Wt;
 
 class Session;
 
-class AuthWidget : public Wt::Auth::AuthWidget
+class AuthWidget : public Auth::AuthWidget
 {
 public:
   AuthWidget(Session& session);
 
   /* We will use a custom registration view */
-  virtual Wt::WWidget *createRegistrationView(const Wt::Auth::Identity& id);
+  virtual std::unique_ptr<WWidget> createRegistrationView(const Auth::Identity& id) override;
 
 private:
   Session& session_;
