@@ -14,7 +14,12 @@ auto item = Wt::cpp14::make_unique<Wt::WText>("Item 1");
 item->setStyleClass("green-box");
 vbox->addWidget(std::move(item), 1);
 
+#ifndef WT_TARGET_JAVA
 auto hbox = vbox->addLayout(Wt::cpp14::make_unique<Wt::WHBoxLayout>());
+#else // WT_TARGET_JAVA
+auto hbox = Wt::cpp14::make_unique<Wt::WHBoxLayout>();
+vbox->addLayout(hbox);
+#endif // WT_TARGET_JAVA
 
 item = Wt::cpp14::make_unique<Wt::WText>("Item 2");
 item->setStyleClass("green-box");
